==> igniteui-react-16.16.2.tgz: package/esm5/lib/igr-move-floating-pane-action.js <==
import { __extends } from "tslib";
import { PaneDragActionType_$type } from "./PaneDragActionType";
import { IgrPaneDragAction } from "./igr-pane-drag-action";
import { MoveFloatingPaneAction } from "./MoveFloatingPaneAction";
import { ensureEnum } from "igniteui-react-core";
var IgrMoveFloatingPaneAction = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrMoveFloatingPaneAction, _super);
    function IgrMoveFloatingPaneAction(props) {
        return _super.call(this, props) || this;
    }
    IgrMoveFloatingPaneAction.prototype.createImplementation = function () {
        return new MoveFloatingPaneAction();
    };
    Object.defineProperty(IgrMoveFloatingPaneAction.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrMoveFloatingPaneAction.prototype, "actionType", {
        get: function () {
            return this.i.c;
        },
        set: function (v) {
            this.i.c = ensureEnum(PaneDragActionType_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrMoveFloatingPaneAction.prototype, "oldLocation", {
        get: function () {
            if (this.i.b == null) {
                return null;
            }
            return this.i.b.externalObject;
        },
        set: function (v) {
            if (v != null && this._stylingContainer && v._styling)
                v._styling(this._stylingContainer, this, this);
            v == null ? this.i.b = null : this.i.b = v.i;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrMoveFloatingPaneAction.prototype, "newLocation", {
        get: function () {
            if (this.i.a == null) {
                return null;
            }
            return this.i.a.externalObject;
        },
        set: function (v) {
            if (v != null && this._stylingContainer && v._styling)
                v._styling(this._stylingContainer, this, this);
            v == null ? this.i.a = null : this.i.a = v.i;
        },
        enumerable: false,
        configurable: true
    });
    IgrMoveFloatingPaneAction.prototype.findByName = function (name) {
        var baseResult = _super.prototype.findByName.call(this, name);
        if (baseResult) {
            return baseResult;
        }
        if (this.oldLocation && this.oldLocation.name && this.oldLocation.name == name) {
            return this.oldLocation;
        }
        if (this.newLocation && this.newLocation.name && this.newLocation.name == name) {
            return this.newLocation;
        }
        return null;
    };
    IgrMoveFloatingPaneAction.prototype._styling = function (container, component, parent) {
        _super.prototype._styling.call(this, container, component, parent);
        this._inStyling = true;
        if (this.oldLocation && this.oldLocation._styling) {
            this.oldLocation._styling(container, component, this);
        }
        if (this.newLocation && this.newLocation._styling) {
            this.newLocation._styling(container, component, this);
        }
        this._inStyling = false;
    };
    return IgrMoveFloatingPaneAction;
}(IgrPaneDragAction));
export { IgrMoveFloatingPaneAction };

==> igniteui-react-18.5.1.tgz: package/esm5/lib/igr-move-floating-pane-action.js <==
import { __extends } from "tslib";
import { PaneDragActionType_$type } from "./PaneDragActionType";
import { IgrDockManagerPoint } from "./igr-dock-manager-point";
import { IgrPaneDragAction } from "./igr-pane-drag-action";
import { MoveFloatingPaneAction } from "./MoveFloatingPaneAction";
import { ensureEnum } from "igniteui-react-core";
var IgrMoveFloatingPaneAction = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrMoveFloatingPaneAction, _super);
    function IgrMoveFloatingPaneAction(props) {
        return _super.call(this, props) || this;
    }
    IgrMoveFloatingPaneAction.prototype.createImplementation = function () {
        return new MoveFloatingPaneAction();
    };
    Object.defineProperty(IgrMoveFloatingPaneAction.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrMoveFloatingPaneAction.prototype, "type", {
        get: function () {
            return this.i.c;
        },
        set: function (v) {
            this.i.c = ensureEnum(PaneDragActionType_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrMoveFloatingPaneAction.prototype, "oldLocation", {
        get: function () {
            var r = this.i.b;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                var e = new IgrDockManagerPoint();
                if (r.$type) {
                    e._implementation = r;
                }
                else {
                    if (e.i.setNativeElement) {
                        e.i.setNativeElement(r);
                    }
                }
                r.externalObject = e;
            }
            return r.externalObject;
        },
        set: function (v) {
            v == null ? this.i.b = null : this.i.b = v.i;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrMoveFloatingPaneAction.prototype, "newLocation", {
        get: function () {
            var r = this.i.a;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                var e = new IgrDockManagerPoint();
                if (r.$type) {
                    e._implementation = r;
                }
                else {
                    if (e.i.setNativeElement) {
                        e.i.setNativeElement(r);
                    }
                }
                r.externalObject = e;
            }
            return r.externalObject;
        },
        set: function (v) {
            v == null ? this.i.a = null : this.i.a = v.i;
        },
        enumerable: false,
        configurable: true
    });
    IgrMoveFloatingPaneAction.prototype.findByName = function (name) {
        var baseResult = _super.prototype.findByName.call(this, name);
        if (baseResult) {
            return baseResult;
        }
        if (this.oldLocation && this.oldLocation.name && this.oldLocation.name == name) {
            return this.oldLocation;
        }
        if (this.newLocation && this.newLocation.name && this.newLocation.name == name) {
            return this.newLocation;
        }
        return null;
    };
    IgrMoveFloatingPaneAction.prototype.setNativeElement = function (element) {
        this.i.setNativeElement(element);
    };
    return IgrMoveFloatingPaneAction;
}(IgrPaneDragAction));
export { IgrMoveFloatingPaneAction };
